### 散点图

散点图有两种：单维度多指标散点图和双维度多指标散点图。

#### 单维度多指标散点图示例：
<iframe width="100%" height="450" src="//jsfiddle.net/vue_echarts/1xjfgz25/embedded/result,html,js/?bodyColor=fff" allowfullscreen="allowfullscreen" frameborder="0"></iframe>

横轴为维度（日期），纵轴为指标（余额，数量，年龄）。

#### 双维度多指标散点图示例：
<iframe width="100%" height="450" src="//jsfiddle.net/vue_echarts/e0hbk316/3/embedded/result,html,js/?bodyColor=fff" allowfullscreen="allowfullscreen" frameborder="0"></iframe>

图例和横轴分别为两个维度(地点，日期)，指标（余额，数量，年龄）展示在 纵轴，散点大小，visualMap 及 tooltip 中。

其中，metrics 数组的第一项（默认为 columns[1]）展示为纵轴，第二项（默认为 columns[2]）展示为散点大小， visualMap 需特殊配置。

visualMap 中的 dimension 属性用于设置数据的哪个指标映射到视觉元素上，接受的是一个数字，代表数据的次序，其中，数据的排序为 dimension, metrics[0], metrics[1], columns 中的其他指标，在上图中的次序就是 日期，余额，数量，年龄，如果想要将年龄映射到视觉元素上，dimension 的值就是 3。

两种类型的图通过数据格式区分:
单维度多指标散点图的数据格式为:
```js
{
  columns: ['日期', '余额', '数量', '年龄'],
  rows: [
    { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
    { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
    { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
    { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
    { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
    { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
  ]
}
```

单维度多指标散点图的数据格式为:
```js
{
  columns: ['日期', '余额', '数量', '年龄'],
  rows: {
    '上海': [
      { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
      { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
      { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
      { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
      { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
      { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
    ],
    '北京': [
      { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
      { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
      { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
      { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
      { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
      { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
    ],
    '广州': [
      { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
      { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
      { '日期': '1-3', '余额': 2123, '年龄': 30, '数量': 3245 },
      { '日期': '1-5', '余额': 4123, '年龄': 12, '数量': 4355 },
      { '日期': '1-4', '余额': 5123, '年龄': 18, '数量': 4564 },
      { '日期': '1-6', '余额': 3843, '年龄': 30, '数量': 4850 }
    ]
  }
}
```

#### 指标维度配置

<vuep template="#set-dim-metrics"></vuep>

<script v-pre type="text/x-template" id="set-dim-metrics">
<template>
  <ve-scatter :data="chartData" :settings="chartSettings"></ve-scatter>
</template>

<script>
  module.exports = {
    created: function () {
      this.chartData = {
        columns: ['日期', '余额', '数量', '年龄'],
        rows: {
          '上海': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
            { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
          ],
          '北京': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
            { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
            { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
          ],
          '广州': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 2123, '年龄': 30, '数量': 3245 },
            { '日期': '1-5', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-4', '余额': 5123, '年龄': 18, '数量': 4564 },
            { '日期': '1-6', '余额': 3843, '年龄': 30, '数量': 4850 }
          ]
        }
      }
      this.chartSettings = {
        dimension: '日期',
        metrics: ['年龄', '数量']
      }
    }
  }
</script>
</script>

#### 数据类型配置

<vuep template="#set-data-type"></vuep>

<script v-pre type="text/x-template" id="set-data-type">
<template>
  <ve-scatter :data="chartData" :settings="chartSettings"></ve-scatter>
</template>

<script>
  module.exports = {
    created: function () {
      this.chartData = {
        columns: ['日期', '余额', '数量', '年龄'],
        rows: {
          '上海': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
            { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
          ],
          '北京': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
            { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
            { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
          ],
          '广州': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 2123, '年龄': 30, '数量': 3245 },
            { '日期': '1-5', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-4', '余额': 5123, '年龄': 18, '数量': 4564 },
            { '日期': '1-6', '余额': 3843, '年龄': 30, '数量': 4850 }
          ]
        }
      }
      this.chartSettings = {
        dataType: {
          '余额': 'KMB',
          '年龄': 'percent',
          '数量': 'normal'
        }
      }
    }
  }
</script>
</script>

#### 样式配置

<vuep template="#set-style"></vuep>

<script v-pre type="text/x-template" id="set-style">
<template>
  <ve-scatter :data="chartData" :settings="chartSettings"></ve-scatter>
</template>

<script>
  module.exports = {
    created: function () {
      this.chartData = {
        columns: ['日期', '余额', '数量', '年龄'],
        rows: {
          '上海': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
            { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
          ],
          '北京': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
            { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
            { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
          ],
          '广州': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 2123, '年龄': 30, '数量': 3245 },
            { '日期': '1-5', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-4', '余额': 5123, '年龄': 18, '数量': 4564 },
            { '日期': '1-6', '余额': 3843, '年龄': 30, '数量': 4850 }
          ]
        }
      }
      this.chartSettings = {
        label: {
          emphasis: {
            show: true,
            position: 'top',
            formatter (param) {
              return param.data.value[0]
            }
          }
        },
        itemStyle: {
          normal: {
            opacity: 0.8,
            shadowBlur: 10,
            shadowOffsetX: 0,
            shadowOffsetY: 0
          }
        }
      }
    }
  }
</script>
</script>

#### 属性名配置

<vuep template="#set-label"></vuep>

<script v-pre type="text/x-template" id="set-label">
<template>
  <ve-scatter :data="chartData" :settings="chartSettings"></ve-scatter>
</template>

<script>
  module.exports = {
    created: function () {
      this.chartData = {
        columns: ['日期', '余额', '数量', '年龄'],
        rows: {
          '上海': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
            { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
          ],
          '北京': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
            { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
            { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
          ],
          '广州': [
            { '日期': '1-1', '余额': 123, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 2123, '年龄': 30, '数量': 3245 },
            { '日期': '1-5', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-4', '余额': 5123, '年龄': 18, '数量': 4564 },
            { '日期': '1-6', '余额': 3843, '年龄': 30, '数量': 4850 }
          ]
        }
      }
      this.chartSettings = {
        legendName: {
          '上海': '上海1'
        },
        labelMap: {
          '余额': 'balance'
        }
      }
    }
  }
</script>
</script>

#### 缩放配置

<vuep template="#set-scale"></vuep>

<script v-pre type="text/x-template" id="set-scale">
<template>
  <ve-scatter :data="chartData" :settings="chartSettings"></ve-scatter>
</template>

<script>
  module.exports = {
    created: function () {
      this.chartData = {
        columns: ['日期', '余额', '数量', '年龄'],
        rows: {
          '上海': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
            { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
          ],
          '北京': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
            { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
            { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
          ],
          '广州': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 2123, '年龄': 30, '数量': 3245 },
            { '日期': '1-5', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-4', '余额': 5123, '年龄': 18, '数量': 4564 },
            { '日期': '1-6', '余额': 3843, '年龄': 30, '数量': 4850 }
          ]
        }
      }
      this.chartSettings = {
        scale: true,
        max: 10000
      }
    }
  }
</script>
</script>

#### 散点样式配置

<vuep template="#set-symbol"></vuep>

<script v-pre type="text/x-template" id="set-symbol">
<template>
  <ve-scatter :data="chartData" :settings="chartSettings"></ve-scatter>
</template>

<script>
  module.exports = {
    created: function () {
      this.chartData = {
        columns: ['日期', '余额', '数量', '年龄'],
        rows: {
          '上海': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
            { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
          ],
          '北京': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
            { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
            { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
          ],
          '广州': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 2123, '年龄': 30, '数量': 3245 },
            { '日期': '1-5', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-4', '余额': 5123, '年龄': 18, '数量': 4564 },
            { '日期': '1-6', '余额': 3843, '年龄': 30, '数量': 4850 }
          ]
        }
      }
      this.chartSettings = {
        symbol: 'rect',
        symbolSizeMax: 30,
        symbolRotate: 45,
        symbolOffset: [10, 10]
      }
    }
  }
</script>
</script>

#### 散点出现覆盖时, 提示框可以改成通过坐标轴触发

<vuep template="#set-trigger"></vuep>

<script v-pre type="text/x-template" id="set-trigger">
<template>
  <ve-scatter :data="chartData" :settings="chartSettings"></ve-scatter>
</template>

<script>
  module.exports = {
    created: function () {
      this.chartData = {
        columns: ['日期', '余额', '数量', '年龄'],
        rows: {
          '上海': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1223, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 7123, '年龄': 9, '数量': 3245 },
            { '日期': '1-4', '余额': 4123, '年龄': 12, '数量': 4355 },
            { '日期': '1-5', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-6', '余额': 2323, '年龄': 20, '数量': 6537 }
          ],
          '北京': [
            { '日期': '1-1', '余额': 1230, '年龄': 3, '数量': 1244 },
            { '日期': '1-2', '余额': 1273, '年龄': 6, '数量': 2344 },
            { '日期': '1-3', '余额': 3123, '年龄': 15, '数量': 4564 },
            { '日期': '1-4', '余额': 2123, '年龄': 9, '数量': 3245 },
            { '日期': '1-5', '余额': 4103, '年龄': 12, '数量': 4355 },
            { '日期': '1-6', '余额': 7123, '年龄': 10, '数量': 3567 }
          ]
        }
      }
      this.chartSettings = {
        tooltipTrigger: 'axis'
      }
    }
  }
</script>
</script>


#### settings 配置项

| 配置项 | 简介 | 类型 | 备注 |
| --- | --- | --- | --- |
| dimension | 维度 | String | 默认 columns[0] |
| metrics | 指标 | Array | 默认 [columns[0], columns[1]] |
| dataType | 数据类型 | Object | - |
| xAxisType | x轴类型 | String | 可选值: category, value, time, log |
| xAxisName | x轴标题 | String | - |
| yAxisName | y轴标题 | String | - |
| digit | 设置数据类型为percent时保留的位数 | Number | 默认为2 |
| labelMap | 设置指标的别名 | Object | - |
| legendName | 设置图表上方图例的别名 | Object | - |
| tooltipTrigger | 提示框的触发方式 | String | 可选值: item, axis |
| axisVisible | 是否显示坐标轴 | Boolean | - |
| symbolSizeMax | 气泡最大值 | Number | 默认为50 |
| symbol | 标记的图形 | String | 内容参考[文档](http://echarts.baidu.com/option.html#series-scatter.symbol) |
| symbolSize | 标记的大小 | number, Array, Function | 内容参考[文档](http://echarts.baidu.com/option.html#series-scatter.symbolSize) |
| symbolRotate | 标记的旋转角度 | number | 内容参考[文档](http://echarts.baidu.com/option.html#series-scatter.symbolRotate) |
| symbolOffset | 标记相对于原本位置的偏移 | Array | 内容参考[文档](http://echarts.baidu.com/option.html#series-scatter.symbolOffset) |
| cursor | 鼠标悬浮时在图形元素上时鼠标的样式 | string | 内容参考[文档](http://echarts.baidu.com/option.html#series-scatter.cursor) |
| scale | 是否是脱离 0 值比例 | Boolean | - |
| min | y轴最小值 | Number | - |
| max | y轴最大值 | Number | - |
| label | 图形上的文本标签 | Object | 内容参考[文档](http://echarts.baidu.com/option.html#series-scatter.label) |
| itemStyle | 图形样式 | Object | 内容参考[文档](http://echarts.baidu.com/option.html#series-scatter.itemStyle) |
